@@ -43,13 +43,13 @@ class TestQuota(testtools.TestCase):
         self.assertEqual('/quotas', sot.base_path)
         self.assertEqual('network', sot.service.service_type)
         self.assertFalse(sot.allow_create)
-        self.assertTrue(sot.allow_retrieve)
+        self.assertTrue(sot.allow_get)
         self.assertTrue(sot.allow_update)
         self.assertTrue(sot.allow_delete)
         self.assertTrue(sot.allow_list)
 
     def test_make_it(self):
-        sot = quota.Quota(EXAMPLE)
+        sot = quota.Quota(**EXAMPLE)
         self.assertEqual(EXAMPLE['floatingip'], sot.floating_ips)
         self.assertEqual(EXAMPLE['network'], sot.networks)
         self.assertEqual(EXAMPLE['port'], sot.ports)
@@ -67,36 +67,43 @@ class TestQuota(testtools.TestCase):
         self.assertEqual(EXAMPLE['l7policy'], sot.l7_policies)
         self.assertEqual(EXAMPLE['pool'], sot.pools)
 
+    def test_prepare_request(self):
+        body = {'id': 'ABCDEFGH', 'network': '12345'}
+        quota_obj = quota.Quota(**body)
+        response = quota_obj._prepare_request()
+        self.assertNotIn('id', response)
+
 
 class TestQuotaDefault(testtools.TestCase):
 
     def test_basic(self):
-        default = quota.QuotaDefault()
-        self.assertEqual('quota', default.resource_key)
-        self.assertEqual('quotas', default.resources_key)
-        self.assertEqual('/quotas/%(project)s/default', default.base_path)
-        self.assertEqual('network', default.service.service_type)
-        self.assertFalse(default.allow_create)
-        self.assertTrue(default.allow_retrieve)
-        self.assertFalse(default.allow_update)
-        self.assertFalse(default.allow_delete)
-        self.assertFalse(default.allow_list)
+        sot = quota.QuotaDefault()
+        self.assertEqual('quota', sot.resource_key)
+        self.assertEqual('quotas', sot.resources_key)
+        self.assertEqual('/quotas/%(project)s/default', sot.base_path)
+        self.assertEqual('network', sot.service.service_type)
+        self.assertFalse(sot.allow_create)
+        self.assertTrue(sot.allow_get)
+        self.assertFalse(sot.allow_update)
+        self.assertFalse(sot.allow_delete)
+        self.assertFalse(sot.allow_list)
 
     def test_make_it(self):
-        default = quota.Quota(EXAMPLE)
-        self.assertEqual(EXAMPLE['floatingip'], default.floating_ips)
-        self.assertEqual(EXAMPLE['network'], default.networks)
-        self.assertEqual(EXAMPLE['port'], default.ports)
-        self.assertEqual(EXAMPLE['tenant_id'], default.project_id)
-        self.assertEqual(EXAMPLE['router'], default.routers)
-        self.assertEqual(EXAMPLE['subnet'], default.subnets)
-        self.assertEqual(EXAMPLE['subnetpool'], default.subnet_pools)
+        sot = quota.QuotaDefault(project='FAKE_PROJECT', **EXAMPLE)
+        self.assertEqual(EXAMPLE['floatingip'], sot.floating_ips)
+        self.assertEqual(EXAMPLE['network'], sot.networks)
+        self.assertEqual(EXAMPLE['port'], sot.ports)
+        self.assertEqual(EXAMPLE['tenant_id'], sot.project_id)
+        self.assertEqual(EXAMPLE['router'], sot.routers)
+        self.assertEqual(EXAMPLE['subnet'], sot.subnets)
+        self.assertEqual(EXAMPLE['subnetpool'], sot.subnet_pools)
         self.assertEqual(EXAMPLE['security_group_rule'],
-                         default.security_group_rules)
-        self.assertEqual(EXAMPLE['security_group'], default.security_groups)
-        self.assertEqual(EXAMPLE['rbac_policy'], default.rbac_policies)
-        self.assertEqual(EXAMPLE['healthmonitor'], default.health_monitors)
-        self.assertEqual(EXAMPLE['listener'], default.listeners)
-        self.assertEqual(EXAMPLE['loadbalancer'], default.load_balancers)
-        self.assertEqual(EXAMPLE['l7policy'], default.l7_policies)
-        self.assertEqual(EXAMPLE['pool'], default.pools)
+                         sot.security_group_rules)
+        self.assertEqual(EXAMPLE['security_group'], sot.security_groups)
+        self.assertEqual(EXAMPLE['rbac_policy'], sot.rbac_policies)
+        self.assertEqual(EXAMPLE['healthmonitor'], sot.health_monitors)
+        self.assertEqual(EXAMPLE['listener'], sot.listeners)
+        self.assertEqual(EXAMPLE['loadbalancer'], sot.load_balancers)
+        self.assertEqual(EXAMPLE['l7policy'], sot.l7_policies)
+        self.assertEqual(EXAMPLE['pool'], sot.pools)
+        self.assertEqual('FAKE_PROJECT', sot.project)
